# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
StdSelect module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_stdselect.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _StdSelect
else:
    import _StdSelect

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _StdSelect.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _StdSelect.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StdSelect.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StdSelect.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _StdSelect.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _StdSelect.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _StdSelect.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _StdSelect.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _StdSelect.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _StdSelect.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StdSelect.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _StdSelect.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _StdSelect.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StdSelect.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StdSelect.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StdSelect.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _StdSelect.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _StdSelect:
_StdSelect.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _StdSelect.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.SelectMgr
import OCC.Core.Graphic3d
import OCC.Core.BVH
import OCC.Core.Quantity
import OCC.Core.TCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.Aspect
import OCC.Core.Image
import OCC.Core.TopLoc
import OCC.Core.Bnd
import OCC.Core.TColgp
import OCC.Core.OSD
import OCC.Core.Media
import OCC.Core.Select3D
import OCC.Core.SelectBasics
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.PrsMgr
import OCC.Core.Prs3d
import OCC.Core.Poly
import OCC.Core.TShort
import OCC.Core.V3d
import OCC.Core.TopAbs
import OCC.Core.TopoDS
import OCC.Core.Message

from enum import IntEnum
from OCC.Core.Exception import *

StdSelect_AnyFace = _StdSelect.StdSelect_AnyFace
StdSelect_Plane = _StdSelect.StdSelect_Plane
StdSelect_Cylinder = _StdSelect.StdSelect_Cylinder
StdSelect_Sphere = _StdSelect.StdSelect_Sphere
StdSelect_Torus = _StdSelect.StdSelect_Torus
StdSelect_Revol = _StdSelect.StdSelect_Revol
StdSelect_Cone = _StdSelect.StdSelect_Cone
StdSelect_AnyEdge = _StdSelect.StdSelect_AnyEdge
StdSelect_Line = _StdSelect.StdSelect_Line
StdSelect_Circle = _StdSelect.StdSelect_Circle
StdSelect_TypeOfSelectionImage_NormalizedDepth = _StdSelect.StdSelect_TypeOfSelectionImage_NormalizedDepth
StdSelect_TypeOfSelectionImage_NormalizedDepthInverted = _StdSelect.StdSelect_TypeOfSelectionImage_NormalizedDepthInverted
StdSelect_TypeOfSelectionImage_UnnormalizedDepth = _StdSelect.StdSelect_TypeOfSelectionImage_UnnormalizedDepth
StdSelect_TypeOfSelectionImage_ColoredDetectedObject = _StdSelect.StdSelect_TypeOfSelectionImage_ColoredDetectedObject
StdSelect_TypeOfSelectionImage_ColoredEntity = _StdSelect.StdSelect_TypeOfSelectionImage_ColoredEntity
StdSelect_TypeOfSelectionImage_ColoredOwner = _StdSelect.StdSelect_TypeOfSelectionImage_ColoredOwner
StdSelect_TypeOfSelectionImage_ColoredSelectionMode = _StdSelect.StdSelect_TypeOfSelectionImage_ColoredSelectionMode


class StdSelect_TypeOfFace(IntEnum):
	StdSelect_AnyFace = 0
	StdSelect_Plane = 1
	StdSelect_Cylinder = 2
	StdSelect_Sphere = 3
	StdSelect_Torus = 4
	StdSelect_Revol = 5
	StdSelect_Cone = 6
StdSelect_AnyFace = StdSelect_TypeOfFace.StdSelect_AnyFace
StdSelect_Plane = StdSelect_TypeOfFace.StdSelect_Plane
StdSelect_Cylinder = StdSelect_TypeOfFace.StdSelect_Cylinder
StdSelect_Sphere = StdSelect_TypeOfFace.StdSelect_Sphere
StdSelect_Torus = StdSelect_TypeOfFace.StdSelect_Torus
StdSelect_Revol = StdSelect_TypeOfFace.StdSelect_Revol
StdSelect_Cone = StdSelect_TypeOfFace.StdSelect_Cone

class StdSelect_TypeOfEdge(IntEnum):
	StdSelect_AnyEdge = 0
	StdSelect_Line = 1
	StdSelect_Circle = 2
StdSelect_AnyEdge = StdSelect_TypeOfEdge.StdSelect_AnyEdge
StdSelect_Line = StdSelect_TypeOfEdge.StdSelect_Line
StdSelect_Circle = StdSelect_TypeOfEdge.StdSelect_Circle

class StdSelect_TypeOfSelectionImage(IntEnum):
	StdSelect_TypeOfSelectionImage_NormalizedDepth = 0
	StdSelect_TypeOfSelectionImage_NormalizedDepthInverted = 1
	StdSelect_TypeOfSelectionImage_UnnormalizedDepth = 2
	StdSelect_TypeOfSelectionImage_ColoredDetectedObject = 3
	StdSelect_TypeOfSelectionImage_ColoredEntity = 4
	StdSelect_TypeOfSelectionImage_ColoredOwner = 5
	StdSelect_TypeOfSelectionImage_ColoredSelectionMode = 6
StdSelect_TypeOfSelectionImage_NormalizedDepth = StdSelect_TypeOfSelectionImage.StdSelect_TypeOfSelectionImage_NormalizedDepth
StdSelect_TypeOfSelectionImage_NormalizedDepthInverted = StdSelect_TypeOfSelectionImage.StdSelect_TypeOfSelectionImage_NormalizedDepthInverted
StdSelect_TypeOfSelectionImage_UnnormalizedDepth = StdSelect_TypeOfSelectionImage.StdSelect_TypeOfSelectionImage_UnnormalizedDepth
StdSelect_TypeOfSelectionImage_ColoredDetectedObject = StdSelect_TypeOfSelectionImage.StdSelect_TypeOfSelectionImage_ColoredDetectedObject
StdSelect_TypeOfSelectionImage_ColoredEntity = StdSelect_TypeOfSelectionImage.StdSelect_TypeOfSelectionImage_ColoredEntity
StdSelect_TypeOfSelectionImage_ColoredOwner = StdSelect_TypeOfSelectionImage.StdSelect_TypeOfSelectionImage_ColoredOwner
StdSelect_TypeOfSelectionImage_ColoredSelectionMode = StdSelect_TypeOfSelectionImage.StdSelect_TypeOfSelectionImage_ColoredSelectionMode


def Handle_StdSelect_BRepOwner_Create() -> "opencascade::handle< StdSelect_BRepOwner >":
    return _StdSelect.Handle_StdSelect_BRepOwner_Create()

def Handle_StdSelect_BRepOwner_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StdSelect_BRepOwner >":
    return _StdSelect.Handle_StdSelect_BRepOwner_DownCast(t)

def Handle_StdSelect_BRepOwner_IsNull(t: "opencascade::handle< StdSelect_BRepOwner > const &") -> "bool":
    return _StdSelect.Handle_StdSelect_BRepOwner_IsNull(t)

def Handle_StdSelect_EdgeFilter_Create() -> "opencascade::handle< StdSelect_EdgeFilter >":
    return _StdSelect.Handle_StdSelect_EdgeFilter_Create()

def Handle_StdSelect_EdgeFilter_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StdSelect_EdgeFilter >":
    return _StdSelect.Handle_StdSelect_EdgeFilter_DownCast(t)

def Handle_StdSelect_EdgeFilter_IsNull(t: "opencascade::handle< StdSelect_EdgeFilter > const &") -> "bool":
    return _StdSelect.Handle_StdSelect_EdgeFilter_IsNull(t)

def Handle_StdSelect_FaceFilter_Create() -> "opencascade::handle< StdSelect_FaceFilter >":
    return _StdSelect.Handle_StdSelect_FaceFilter_Create()

def Handle_StdSelect_FaceFilter_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StdSelect_FaceFilter >":
    return _StdSelect.Handle_StdSelect_FaceFilter_DownCast(t)

def Handle_StdSelect_FaceFilter_IsNull(t: "opencascade::handle< StdSelect_FaceFilter > const &") -> "bool":
    return _StdSelect.Handle_StdSelect_FaceFilter_IsNull(t)

def Handle_StdSelect_Shape_Create() -> "opencascade::handle< StdSelect_Shape >":
    return _StdSelect.Handle_StdSelect_Shape_Create()

def Handle_StdSelect_Shape_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StdSelect_Shape >":
    return _StdSelect.Handle_StdSelect_Shape_DownCast(t)

def Handle_StdSelect_Shape_IsNull(t: "opencascade::handle< StdSelect_Shape > const &") -> "bool":
    return _StdSelect.Handle_StdSelect_Shape_IsNull(t)

def Handle_StdSelect_ShapeTypeFilter_Create() -> "opencascade::handle< StdSelect_ShapeTypeFilter >":
    return _StdSelect.Handle_StdSelect_ShapeTypeFilter_Create()

def Handle_StdSelect_ShapeTypeFilter_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StdSelect_ShapeTypeFilter >":
    return _StdSelect.Handle_StdSelect_ShapeTypeFilter_DownCast(t)

def Handle_StdSelect_ShapeTypeFilter_IsNull(t: "opencascade::handle< StdSelect_ShapeTypeFilter > const &") -> "bool":
    return _StdSelect.Handle_StdSelect_ShapeTypeFilter_IsNull(t)
class stdselect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def SetDrawerForBRepOwner(*args) -> "void":
        r"""
        Puts the same drawer in every brepowner of sensitiveprimitive used only for hilight of brepowner...

        Parameters
        ----------
        aSelection: SelectMgr_Selection
        aDrawer: Prs3d_Drawer

        Returns
        -------
        None

        """
        return _StdSelect.stdselect_SetDrawerForBRepOwner(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _StdSelect.stdselect_swiginit(self, _StdSelect.new_stdselect())
    __swig_destroy__ = _StdSelect.delete_stdselect

# Register stdselect in _StdSelect:
_StdSelect.stdselect_swigregister(stdselect)

def stdselect_SetDrawerForBRepOwner(*args) -> "void":
    r"""
    Puts the same drawer in every brepowner of sensitiveprimitive used only for hilight of brepowner...

    Parameters
    ----------
    aSelection: SelectMgr_Selection
    aDrawer: Prs3d_Drawer

    Returns
    -------
    None

    """
    return _StdSelect.stdselect_SetDrawerForBRepOwner(*args)

class StdSelect_BRepOwner(OCC.Core.SelectMgr.SelectMgr_EntityOwner):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an owner specification framework defined by the priority apriority.

        Parameters
        ----------
        aPriority: int

        Returns
        -------
        None
        Constructs an owner specification framework defined by the shape ashape and the priority apriority. ashape and apriority are stored in this framework. if more than one owner are detected during dynamic selection, the one with the highest priority is the one stored.

        Parameters
        ----------
        aShape: TopoDS_Shape
        aPriority: int,optional
        	default value is 0
        ComesFromDecomposition: bool,optional
        	default value is Standard_False

        Returns
        -------
        None
        Constructs an owner specification framework defined by the shape ashape, the selectable object theorigin and the priority apriority. ashape, theorigin and apriority are stored in this framework. if more than one owner are detected during dynamic selection, the one with the highest priority is the one stored.

        Parameters
        ----------
        aShape: TopoDS_Shape
        theOrigin: SelectMgr_SelectableObject
        aPriority: int,optional
        	default value is 0
        FromDecomposition: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        _StdSelect.StdSelect_BRepOwner_swiginit(self, _StdSelect.new_StdSelect_BRepOwner(*args))

    def DumpJsonToString(self, depth: "int"=-1) -> "std::string":
        r"""DumpJsonToString(StdSelect_BRepOwner self, int depth=-1) -> std::string"""
        return _StdSelect.StdSelect_BRepOwner_DumpJsonToString(self, depth)

    def HasHilightMode(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if this framework has a highlight mode defined for it.

        Returns
        -------
        bool

        """
        return _StdSelect.StdSelect_BRepOwner_HasHilightMode(self, *args)

    def HasShape(self, *args) -> "Standard_Boolean":
        r"""
        Returns false if no shape was set.

        Returns
        -------
        bool

        """
        return _StdSelect.StdSelect_BRepOwner_HasShape(self, *args)

    def HilightMode(self, *args) -> "Standard_Integer":
        r"""
        Returns the highlight mode for this framework. this defines the type of display used to highlight the owner of the shape when it is detected by the selector. the default type of display is wireframe, defined by the index 0.

        Returns
        -------
        int

        """
        return _StdSelect.StdSelect_BRepOwner_HilightMode(self, *args)

    def ResetHilightMode(self, *args) -> "void":
        r"""
        Resets the higlight mode for this framework. this defines the type of display used to highlight the owner of the shape when it is detected by the selector. the default type of display is wireframe, defined by the index 0.

        Returns
        -------
        None

        """
        return _StdSelect.StdSelect_BRepOwner_ResetHilightMode(self, *args)

    def SetHilightMode(self, *args) -> "void":
        r"""
        Sets the highlight mode for this framework. this defines the type of display used to highlight the owner of the shape when it is detected by the selector. the default type of display is wireframe, defined by the index 0.

        Parameters
        ----------
        theMode: int

        Returns
        -------
        None

        """
        return _StdSelect.StdSelect_BRepOwner_SetHilightMode(self, *args)

    def Shape(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns the shape.

        Returns
        -------
        TopoDS_Shape

        """
        return _StdSelect.StdSelect_BRepOwner_Shape(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StdSelect_BRepOwner_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StdSelect.delete_StdSelect_BRepOwner

# Register StdSelect_BRepOwner in _StdSelect:
_StdSelect.StdSelect_BRepOwner_swigregister(StdSelect_BRepOwner)

class StdSelect_BRepSelectionTool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def ComputeSensitive(*args) -> "void":
        r"""
        Computes the sensitive primitives, stores them in the selectmgr_selection object, and returns this object. @param theshape shape to compute sensitive entities @param theowner selectable owner object @param theselection selection to append new sensitive entities @param thedeflection linear deflection @param thedeflangle angular deflection @param thenbponedge sensitivity parameters for edges and wires @param themaxiparam sensitivity parameters for infinite objects (the default value is 500) @param theautotriang flag to compute triangulation for the faces which have none.

        Parameters
        ----------
        theShape: TopoDS_Shape
        theOwner: SelectMgr_EntityOwner
        theSelection: SelectMgr_Selection
        theDeflection: float
        theDeflAngle: float
        theNbPOnEdge: int
        theMaxiParam: float
        theAutoTriang: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _StdSelect.StdSelect_BRepSelectionTool_ComputeSensitive(*args)

    @staticmethod
    def GetEdgeSensitive(*args) -> "void":
        r"""
        Create a sensitive edge or sensitive wire. @param theshape either topods_edge or topods_wire to compute sensitive entities @param theowner selectable owner object @param theselection selection to append new sensitive entities @param thedeflection linear deflection @param thedeviationangle angular deflection @param thenbponedge sensitivity parameters @param themaxiparam sensitivity parameters.

        Parameters
        ----------
        theShape: TopoDS_Shape
        theOwner: SelectMgr_EntityOwner
        theSelection: SelectMgr_Selection
        theDeflection: float
        theDeviationAngle: float
        theNbPOnEdge: int
        theMaxiParam: float
        theSensitive: Select3D_SensitiveEntity

        Returns
        -------
        None

        """
        return _StdSelect.StdSelect_BRepSelectionTool_GetEdgeSensitive(*args)

    @staticmethod
    def GetSensitiveForFace(*args) -> "Standard_Boolean":
        r"""
        Creates the 3d sensitive entities for face selection. @param theface face to compute sensitive entities @param theowner selectable owner object @param theoutlist output result list to append created entities @param theautotriang obsolete flag (has no effect) @param thenbponedge sensitivity parameters @param themaxiparam sensitivity parameters @param theinteriorflag flag indicating that face interior (true) or face boundary (false) should be selectable.

        Parameters
        ----------
        theFace: TopoDS_Face
        theOwner: SelectMgr_EntityOwner
        theOutList: Select3D_EntitySequence
        theAutoTriang: bool,optional
        	default value is Standard_True
        theNbPOnEdge: int,optional
        	default value is 9
        theMaxiParam: float,optional
        	default value is 500
        theInteriorFlag: bool,optional
        	default value is Standard_True

        Returns
        -------
        bool

        """
        return _StdSelect.StdSelect_BRepSelectionTool_GetSensitiveForFace(*args)

    @staticmethod
    def GetStandardPriority(*args) -> "Standard_Integer":
        r"""
        Returns the standard priority of the shape ashap having the type atype. this priority is passed to a stdselect_brepowner object. you can use the function load to modify the selection priority of an owner to make one entity more selectable than another one.

        Parameters
        ----------
        theShape: TopoDS_Shape
        theType: TopAbs_ShapeEnum

        Returns
        -------
        int

        """
        return _StdSelect.StdSelect_BRepSelectionTool_GetStandardPriority(*args)

    @staticmethod
    def Load(*args) -> "void":
        r"""
        Decomposition of <ashape> into sensitive entities following a mode of decomposition <atype>. these entities are stored in <aselection>. brepowners are created to store the identity of the picked shapes during the selection process. in those brepowners is also stored the original shape. but one can't get the selectable object which was decomposed to give the sensitive entities. maximal parameter is used for infinite objects, to limit the sensitive domain.... if autotriangulation = true, a triangulation will be computed for faces which have no existing one. if autotriangulation = false the old algorithm will be called to compute sensitive entities on faces.

        Parameters
        ----------
        aSelection: SelectMgr_Selection
        aShape: TopoDS_Shape
        aType: TopAbs_ShapeEnum
        theDeflection: float
        theDeviationAngle: float
        AutoTriangulation: bool,optional
        	default value is Standard_True
        aPriority: int,optional
        	default value is -1
        NbPOnEdge: int,optional
        	default value is 9
        MaximalParameter: float,optional
        	default value is 500

        Returns
        -------
        None
        Same functionnalities ; the only difference is that the selectable object from which the selection comes is stored in each sensitive entityowner; decomposition of <ashape> into sensitive entities following a mode of decomposition <atype>. these entities are stored in <aselection> the major difference is that the known users are first inserted in the brepowners. the original shape is the last user... (see entityowner from selectbasics and brepowner)...

        Parameters
        ----------
        aSelection: SelectMgr_Selection
        Origin: SelectMgr_SelectableObject
        aShape: TopoDS_Shape
        aType: TopAbs_ShapeEnum
        theDeflection: float
        theDeviationAngle: float
        AutoTriangulation: bool,optional
        	default value is Standard_True
        aPriority: int,optional
        	default value is -1
        NbPOnEdge: int,optional
        	default value is 9
        MaximalParameter: float,optional
        	default value is 500

        Returns
        -------
        None

        """
        return _StdSelect.StdSelect_BRepSelectionTool_Load(*args)

    @staticmethod
    def PreBuildBVH(*args) -> "void":
        r"""
        Traverses the selection given and pre-builds bvh trees for heavyweight sensitive entities containing more than bvh_primitive_limit (defined in .cxx file) sub-elements.

        Parameters
        ----------
        theSelection: SelectMgr_Selection

        Returns
        -------
        None

        """
        return _StdSelect.StdSelect_BRepSelectionTool_PreBuildBVH(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _StdSelect.StdSelect_BRepSelectionTool_swiginit(self, _StdSelect.new_StdSelect_BRepSelectionTool())
    __swig_destroy__ = _StdSelect.delete_StdSelect_BRepSelectionTool

# Register StdSelect_BRepSelectionTool in _StdSelect:
_StdSelect.StdSelect_BRepSelectionTool_swigregister(StdSelect_BRepSelectionTool)

def StdSelect_BRepSelectionTool_ComputeSensitive(*args) -> "void":
    r"""
    Computes the sensitive primitives, stores them in the selectmgr_selection object, and returns this object. @param theshape shape to compute sensitive entities @param theowner selectable owner object @param theselection selection to append new sensitive entities @param thedeflection linear deflection @param thedeflangle angular deflection @param thenbponedge sensitivity parameters for edges and wires @param themaxiparam sensitivity parameters for infinite objects (the default value is 500) @param theautotriang flag to compute triangulation for the faces which have none.

    Parameters
    ----------
    theShape: TopoDS_Shape
    theOwner: SelectMgr_EntityOwner
    theSelection: SelectMgr_Selection
    theDeflection: float
    theDeflAngle: float
    theNbPOnEdge: int
    theMaxiParam: float
    theAutoTriang: bool,optional
    	default value is Standard_True

    Returns
    -------
    None

    """
    return _StdSelect.StdSelect_BRepSelectionTool_ComputeSensitive(*args)

def StdSelect_BRepSelectionTool_GetEdgeSensitive(*args) -> "void":
    r"""
    Create a sensitive edge or sensitive wire. @param theshape either topods_edge or topods_wire to compute sensitive entities @param theowner selectable owner object @param theselection selection to append new sensitive entities @param thedeflection linear deflection @param thedeviationangle angular deflection @param thenbponedge sensitivity parameters @param themaxiparam sensitivity parameters.

    Parameters
    ----------
    theShape: TopoDS_Shape
    theOwner: SelectMgr_EntityOwner
    theSelection: SelectMgr_Selection
    theDeflection: float
    theDeviationAngle: float
    theNbPOnEdge: int
    theMaxiParam: float
    theSensitive: Select3D_SensitiveEntity

    Returns
    -------
    None

    """
    return _StdSelect.StdSelect_BRepSelectionTool_GetEdgeSensitive(*args)

def StdSelect_BRepSelectionTool_GetSensitiveForFace(*args) -> "Standard_Boolean":
    r"""
    Creates the 3d sensitive entities for face selection. @param theface face to compute sensitive entities @param theowner selectable owner object @param theoutlist output result list to append created entities @param theautotriang obsolete flag (has no effect) @param thenbponedge sensitivity parameters @param themaxiparam sensitivity parameters @param theinteriorflag flag indicating that face interior (true) or face boundary (false) should be selectable.

    Parameters
    ----------
    theFace: TopoDS_Face
    theOwner: SelectMgr_EntityOwner
    theOutList: Select3D_EntitySequence
    theAutoTriang: bool,optional
    	default value is Standard_True
    theNbPOnEdge: int,optional
    	default value is 9
    theMaxiParam: float,optional
    	default value is 500
    theInteriorFlag: bool,optional
    	default value is Standard_True

    Returns
    -------
    bool

    """
    return _StdSelect.StdSelect_BRepSelectionTool_GetSensitiveForFace(*args)

def StdSelect_BRepSelectionTool_GetStandardPriority(*args) -> "Standard_Integer":
    r"""
    Returns the standard priority of the shape ashap having the type atype. this priority is passed to a stdselect_brepowner object. you can use the function load to modify the selection priority of an owner to make one entity more selectable than another one.

    Parameters
    ----------
    theShape: TopoDS_Shape
    theType: TopAbs_ShapeEnum

    Returns
    -------
    int

    """
    return _StdSelect.StdSelect_BRepSelectionTool_GetStandardPriority(*args)

def StdSelect_BRepSelectionTool_Load(*args) -> "void":
    r"""
    Decomposition of <ashape> into sensitive entities following a mode of decomposition <atype>. these entities are stored in <aselection>. brepowners are created to store the identity of the picked shapes during the selection process. in those brepowners is also stored the original shape. but one can't get the selectable object which was decomposed to give the sensitive entities. maximal parameter is used for infinite objects, to limit the sensitive domain.... if autotriangulation = true, a triangulation will be computed for faces which have no existing one. if autotriangulation = false the old algorithm will be called to compute sensitive entities on faces.

    Parameters
    ----------
    aSelection: SelectMgr_Selection
    aShape: TopoDS_Shape
    aType: TopAbs_ShapeEnum
    theDeflection: float
    theDeviationAngle: float
    AutoTriangulation: bool,optional
    	default value is Standard_True
    aPriority: int,optional
    	default value is -1
    NbPOnEdge: int,optional
    	default value is 9
    MaximalParameter: float,optional
    	default value is 500

    Returns
    -------
    None
    Same functionnalities ; the only difference is that the selectable object from which the selection comes is stored in each sensitive entityowner; decomposition of <ashape> into sensitive entities following a mode of decomposition <atype>. these entities are stored in <aselection> the major difference is that the known users are first inserted in the brepowners. the original shape is the last user... (see entityowner from selectbasics and brepowner)...

    Parameters
    ----------
    aSelection: SelectMgr_Selection
    Origin: SelectMgr_SelectableObject
    aShape: TopoDS_Shape
    aType: TopAbs_ShapeEnum
    theDeflection: float
    theDeviationAngle: float
    AutoTriangulation: bool,optional
    	default value is Standard_True
    aPriority: int,optional
    	default value is -1
    NbPOnEdge: int,optional
    	default value is 9
    MaximalParameter: float,optional
    	default value is 500

    Returns
    -------
    None

    """
    return _StdSelect.StdSelect_BRepSelectionTool_Load(*args)

def StdSelect_BRepSelectionTool_PreBuildBVH(*args) -> "void":
    r"""
    Traverses the selection given and pre-builds bvh trees for heavyweight sensitive entities containing more than bvh_primitive_limit (defined in .cxx file) sub-elements.

    Parameters
    ----------
    theSelection: SelectMgr_Selection

    Returns
    -------
    None

    """
    return _StdSelect.StdSelect_BRepSelectionTool_PreBuildBVH(*args)

class StdSelect_EdgeFilter(OCC.Core.SelectMgr.SelectMgr_Filter):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an edge filter object defined by the type of edge edge.

        Parameters
        ----------
        Edge: StdSelect_TypeOfEdge

        Returns
        -------
        None

        """
        _StdSelect.StdSelect_EdgeFilter_swiginit(self, _StdSelect.new_StdSelect_EdgeFilter(*args))

    def SetType(self, *args) -> "void":
        r"""
        Sets the type of edge anewtype. anewtype is to be highlighted in selection.

        Parameters
        ----------
        aNewType: StdSelect_TypeOfEdge

        Returns
        -------
        None

        """
        return _StdSelect.StdSelect_EdgeFilter_SetType(self, *args)

    def Type(self, *args) -> "StdSelect_TypeOfEdge":
        r"""
        Returns the type of edge to be highlighted in selection.

        Returns
        -------
        StdSelect_TypeOfEdge

        """
        return _StdSelect.StdSelect_EdgeFilter_Type(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StdSelect_EdgeFilter_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StdSelect.delete_StdSelect_EdgeFilter

# Register StdSelect_EdgeFilter in _StdSelect:
_StdSelect.StdSelect_EdgeFilter_swigregister(StdSelect_EdgeFilter)

class StdSelect_FaceFilter(OCC.Core.SelectMgr.SelectMgr_Filter):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs a face filter object defined by the type of face atypeofface.

        Parameters
        ----------
        aTypeOfFace: StdSelect_TypeOfFace

        Returns
        -------
        None

        """
        _StdSelect.StdSelect_FaceFilter_swiginit(self, _StdSelect.new_StdSelect_FaceFilter(*args))

    def SetType(self, *args) -> "void":
        r"""
        Sets the type of face anewtype. anewtype is to be highlighted in selection.

        Parameters
        ----------
        aNewType: StdSelect_TypeOfFace

        Returns
        -------
        None

        """
        return _StdSelect.StdSelect_FaceFilter_SetType(self, *args)

    def Type(self, *args) -> "StdSelect_TypeOfFace":
        r"""
        Returns the type of face to be highlighted in selection.

        Returns
        -------
        StdSelect_TypeOfFace

        """
        return _StdSelect.StdSelect_FaceFilter_Type(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StdSelect_FaceFilter_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StdSelect.delete_StdSelect_FaceFilter

# Register StdSelect_FaceFilter in _StdSelect:
_StdSelect.StdSelect_FaceFilter_swigregister(StdSelect_FaceFilter)

class StdSelect_Shape(OCC.Core.PrsMgr.PrsMgr_PresentableObject):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theShape: TopoDS_Shape
        theDrawer: Prs3d_Drawer,optional
        	default value is opencascade::handle<Prs3d_Drawer>()

        Returns
        -------
        None

        """
        _StdSelect.StdSelect_Shape_swiginit(self, _StdSelect.new_StdSelect_Shape(*args))

    def Compute(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPresentationManager: PrsMgr_PresentationManager3d
        aPresentation: Prs3d_Presentation
        aMode: int,optional
        	default value is 0

        Returns
        -------
        None

        """
        return _StdSelect.StdSelect_Shape_Compute(self, *args)

    def DumpJsonToString(self, depth: "int"=-1) -> "std::string":
        r"""DumpJsonToString(StdSelect_Shape self, int depth=-1) -> std::string"""
        return _StdSelect.StdSelect_Shape_DumpJsonToString(self, depth)

    def Shape(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Shape
        No available documentation.

        Parameters
        ----------
        theShape: TopoDS_Shape

        Returns
        -------
        None

        """
        return _StdSelect.StdSelect_Shape_Shape(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StdSelect_Shape_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StdSelect.delete_StdSelect_Shape

# Register StdSelect_Shape in _StdSelect:
_StdSelect.StdSelect_Shape_swigregister(StdSelect_Shape)

class StdSelect_ShapeTypeFilter(OCC.Core.SelectMgr.SelectMgr_Filter):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs a filter object defined by the shape type atype.

        Parameters
        ----------
        aType: TopAbs_ShapeEnum

        Returns
        -------
        None

        """
        _StdSelect.StdSelect_ShapeTypeFilter_swiginit(self, _StdSelect.new_StdSelect_ShapeTypeFilter(*args))

    def Type(self, *args) -> "TopAbs_ShapeEnum":
        r"""
        Returns the type of shape selected by the filter.

        Returns
        -------
        TopAbs_ShapeEnum

        """
        return _StdSelect.StdSelect_ShapeTypeFilter_Type(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StdSelect_ShapeTypeFilter_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StdSelect.delete_StdSelect_ShapeTypeFilter

# Register StdSelect_ShapeTypeFilter in _StdSelect:
_StdSelect.StdSelect_ShapeTypeFilter_swigregister(StdSelect_ShapeTypeFilter)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *

#the following typedef cannot be wrapped as is
TopLoc_IndexedMapOfLocation = NewType('TopLoc_IndexedMapOfLocation', Any)
#the following typedef cannot be wrapped as is
TopLoc_MapIteratorOfMapOfLocation = NewType('TopLoc_MapIteratorOfMapOfLocation', Any)
#the following typedef cannot be wrapped as is
TopLoc_MapLocationHasher = NewType('TopLoc_MapLocationHasher', Any)
#the following typedef cannot be wrapped as is
TopLoc_MapOfLocation = NewType('TopLoc_MapOfLocation', Any)

class TopLoc_Datum3D(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, T: gp_Trsf) -> None: ...
	def Form(self) -> gp_TrsfForm: ...
	def Transformation(self) -> gp_Trsf: ...
	def Trsf(self) -> gp_Trsf: ...

class TopLoc_ItemLocation:
	def __init__(self, D: TopLoc_Datum3D, P: int) -> None: ...

class TopLoc_Location:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, T: gp_Trsf) -> None: ...
	@overload
	def __init__(self, D: TopLoc_Datum3D) -> None: ...
	def Divided(self, Other: TopLoc_Location) -> TopLoc_Location: ...
	def FirstDatum(self) -> TopLoc_Datum3D: ...
	def FirstPower(self) -> int: ...
	def HashCode(self, theUpperBound: int) -> int: ...
	def Identity(self) -> None: ...
	def Inverted(self) -> TopLoc_Location: ...
	def IsDifferent(self, Other: TopLoc_Location) -> bool: ...
	def IsEqual(self, Other: TopLoc_Location) -> bool: ...
	def IsIdentity(self) -> bool: ...
	def Multiplied(self, Other: TopLoc_Location) -> TopLoc_Location: ...
	def NextLocation(self) -> TopLoc_Location: ...
	def Powered(self, pwr: int) -> TopLoc_Location: ...
	def Predivided(self, Other: TopLoc_Location) -> TopLoc_Location: ...
	def Transformation(self) -> gp_Trsf: ...

class TopLoc_SListNodeOfItemLocation(Standard_Transient):
	def __init__(self, I: TopLoc_ItemLocation, aTail: TopLoc_SListOfItemLocation) -> None: ...
	def Tail(self) -> TopLoc_SListOfItemLocation: ...
	def Value(self) -> TopLoc_ItemLocation: ...

class TopLoc_SListOfItemLocation:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, anItem: TopLoc_ItemLocation, aTail: TopLoc_SListOfItemLocation) -> None: ...
	@overload
	def __init__(self, Other: TopLoc_SListOfItemLocation) -> None: ...
	@overload
	def __init__(self, theOther: TopLoc_SListOfItemLocation) -> None: ...
	def Assign(self, Other: TopLoc_SListOfItemLocation) -> TopLoc_SListOfItemLocation: ...
	def Clear(self) -> None: ...
	def Construct(self, anItem: TopLoc_ItemLocation) -> None: ...
	def IsEmpty(self) -> bool: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Tail(self) -> TopLoc_SListOfItemLocation: ...
	def ToTail(self) -> None: ...
	def Value(self) -> TopLoc_ItemLocation: ...

# harray1 classes
# harray2 classes
# hsequence classes




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XmlXCAFDrivers module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xmlxcafdrivers.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XmlXCAFDrivers
else:
    import _XmlXCAFDrivers

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XmlXCAFDrivers.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XmlXCAFDrivers.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlXCAFDrivers.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlXCAFDrivers.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XmlXCAFDrivers.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XmlXCAFDrivers.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XmlXCAFDrivers.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XmlXCAFDrivers.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XmlXCAFDrivers.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XmlXCAFDrivers.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlXCAFDrivers.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XmlXCAFDrivers.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XmlXCAFDrivers.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlXCAFDrivers.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlXCAFDrivers.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlXCAFDrivers.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XmlXCAFDrivers.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XmlXCAFDrivers:
_XmlXCAFDrivers.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XmlXCAFDrivers.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TDocStd
import OCC.Core.TDF
import OCC.Core.TCollection
import OCC.Core.TColStd
import OCC.Core.CDF
import OCC.Core.CDM
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.Resource
import OCC.Core.PCDM
import OCC.Core.Storage
import OCC.Core.XmlDrivers
import OCC.Core.XmlMDF
import OCC.Core.XmlObjMgt
import OCC.Core.LDOM
import OCC.Core.gp
import OCC.Core.XmlLDrivers

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_XmlXCAFDrivers_DocumentRetrievalDriver_Create() -> "opencascade::handle< XmlXCAFDrivers_DocumentRetrievalDriver >":
    return _XmlXCAFDrivers.Handle_XmlXCAFDrivers_DocumentRetrievalDriver_Create()

def Handle_XmlXCAFDrivers_DocumentRetrievalDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlXCAFDrivers_DocumentRetrievalDriver >":
    return _XmlXCAFDrivers.Handle_XmlXCAFDrivers_DocumentRetrievalDriver_DownCast(t)

def Handle_XmlXCAFDrivers_DocumentRetrievalDriver_IsNull(t: "opencascade::handle< XmlXCAFDrivers_DocumentRetrievalDriver > const &") -> "bool":
    return _XmlXCAFDrivers.Handle_XmlXCAFDrivers_DocumentRetrievalDriver_IsNull(t)

def Handle_XmlXCAFDrivers_DocumentStorageDriver_Create() -> "opencascade::handle< XmlXCAFDrivers_DocumentStorageDriver >":
    return _XmlXCAFDrivers.Handle_XmlXCAFDrivers_DocumentStorageDriver_Create()

def Handle_XmlXCAFDrivers_DocumentStorageDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlXCAFDrivers_DocumentStorageDriver >":
    return _XmlXCAFDrivers.Handle_XmlXCAFDrivers_DocumentStorageDriver_DownCast(t)

def Handle_XmlXCAFDrivers_DocumentStorageDriver_IsNull(t: "opencascade::handle< XmlXCAFDrivers_DocumentStorageDriver > const &") -> "bool":
    return _XmlXCAFDrivers.Handle_XmlXCAFDrivers_DocumentStorageDriver_IsNull(t)
class xmlxcafdrivers(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def DefineFormat(*args) -> "void":
        r"""
        Defines format 'xmlxcaf' and registers its read and write drivers in the specified application.

        Parameters
        ----------
        theApp: TDocStd_Application

        Returns
        -------
        None

        """
        return _XmlXCAFDrivers.xmlxcafdrivers_DefineFormat(*args)

    @staticmethod
    def Factory(*args) -> "opencascade::handle< Standard_Transient > const &":
        r"""
        Depending from the id, returns a list of storage or retrieval attribute drivers. used for plugin. //! standard data model drivers =========================== 47b0b826-d931-11d1-b5da-00a0c9064368 transient-persistent 47b0b827-d931-11d1-b5da-00a0c9064368 persistent-transient //! xcaf data model drivers ================================= ed8793f8-3142-11d4-b9b5-0060b0ee281b transient-persistent ed8793f9-3142-11d4-b9b5-0060b0ee281b persistent-transient ed8793fa-3142-11d4-b9b5-0060b0ee281b xcafschema.

        Parameters
        ----------
        aGUID: Standard_GUID

        Returns
        -------
        opencascade::handle<Standard_Transient>

        """
        return _XmlXCAFDrivers.xmlxcafdrivers_Factory(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlXCAFDrivers.xmlxcafdrivers_swiginit(self, _XmlXCAFDrivers.new_xmlxcafdrivers())
    __swig_destroy__ = _XmlXCAFDrivers.delete_xmlxcafdrivers

# Register xmlxcafdrivers in _XmlXCAFDrivers:
_XmlXCAFDrivers.xmlxcafdrivers_swigregister(xmlxcafdrivers)

def xmlxcafdrivers_DefineFormat(*args) -> "void":
    r"""
    Defines format 'xmlxcaf' and registers its read and write drivers in the specified application.

    Parameters
    ----------
    theApp: TDocStd_Application

    Returns
    -------
    None

    """
    return _XmlXCAFDrivers.xmlxcafdrivers_DefineFormat(*args)

def xmlxcafdrivers_Factory(*args) -> "opencascade::handle< Standard_Transient > const &":
    r"""
    Depending from the id, returns a list of storage or retrieval attribute drivers. used for plugin. //! standard data model drivers =========================== 47b0b826-d931-11d1-b5da-00a0c9064368 transient-persistent 47b0b827-d931-11d1-b5da-00a0c9064368 persistent-transient //! xcaf data model drivers ================================= ed8793f8-3142-11d4-b9b5-0060b0ee281b transient-persistent ed8793f9-3142-11d4-b9b5-0060b0ee281b persistent-transient ed8793fa-3142-11d4-b9b5-0060b0ee281b xcafschema.

    Parameters
    ----------
    aGUID: Standard_GUID

    Returns
    -------
    opencascade::handle<Standard_Transient>

    """
    return _XmlXCAFDrivers.xmlxcafdrivers_Factory(*args)

class XmlXCAFDrivers_DocumentRetrievalDriver(OCC.Core.XmlDrivers.XmlDrivers_DocumentRetrievalDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _XmlXCAFDrivers.XmlXCAFDrivers_DocumentRetrievalDriver_swiginit(self, _XmlXCAFDrivers.new_XmlXCAFDrivers_DocumentRetrievalDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_XmlXCAFDrivers_DocumentRetrievalDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlXCAFDrivers.delete_XmlXCAFDrivers_DocumentRetrievalDriver

# Register XmlXCAFDrivers_DocumentRetrievalDriver in _XmlXCAFDrivers:
_XmlXCAFDrivers.XmlXCAFDrivers_DocumentRetrievalDriver_swigregister(XmlXCAFDrivers_DocumentRetrievalDriver)

class XmlXCAFDrivers_DocumentStorageDriver(OCC.Core.XmlDrivers.XmlDrivers_DocumentStorageDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theCopyright: TCollection_ExtendedString

        Returns
        -------
        None

        """
        _XmlXCAFDrivers.XmlXCAFDrivers_DocumentStorageDriver_swiginit(self, _XmlXCAFDrivers.new_XmlXCAFDrivers_DocumentStorageDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_XmlXCAFDrivers_DocumentStorageDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlXCAFDrivers.delete_XmlXCAFDrivers_DocumentStorageDriver

# Register XmlXCAFDrivers_DocumentStorageDriver in _XmlXCAFDrivers:
_XmlXCAFDrivers.XmlXCAFDrivers_DocumentStorageDriver_swigregister(XmlXCAFDrivers_DocumentStorageDriver)





